## Quick Start 

<pre>
mkdir <name-your-dir>
cd <name-your-dir>

python -m venv .venv
source .venv/bin/activate

pip install -U pip
pip install bmomd numpy pandas python-dotenv scikit-learn category_encoders plotly typing-extensions IPython
</pre>

## example usage
<pre>
import bmoml.nannyml as nml
</pre>



## sources
https://medium.com/@pietrassyk/building-a-custom-pip-library-for-python-fe618034d54a
https://packaging.python.org/en/latest/tutorials/packaging-projects/
